@@ -4,7 +4,7 @@ from django_form_generator.api import views
 
 urlpatterns = [
     path('forms/', views.FormAPIView.as_view(), name="api_forms"),
-    path('form/<int:pk>/', views.FormGeneratorAPIView.as_view(), name="api_form_detail"),
+    path('forms/<int:pk>/', views.FormGeneratorAPIView.as_view(), name="api_form_detail"),
     path('form-response/<uuid:unique_id>/', views.FormGeneratorResponseAPIView.as_view(), name="api_form_response"),
 ]
 
