@@ -8,7 +8,7 @@ DEFAULTS = {
     # 'MAX_UPLOAD_FILE_SIZE': 5242880,
     'FORM_GENERATOR_FORM': 'django_form_generator.forms.FormGeneratorForm',
     'FORM_RESPONSE_FORM': 'django_form_generator.forms.FormGeneratorResponseForm',
-    'FORM_THEME_CHOICES': 'django_form_generator.const.FormTheme',
+    'FORM_STYLE_CHOICES': 'django_form_generator.const.FormStyle',
     'FORM_MANAGER': 'django_form_generator.managers.FormManager',
     'FORM_GENERATOR_RESPONSE_MODEL': 'django_form_generator.models.FormResponse',
     'FORM_GENERATOR_SERIALIZER': 'django_form_generator.api.serializers.FormGeneratorSerializer',
@@ -20,7 +20,7 @@ IMPORT_STRINGS = [
     'FORM_RESPONSE_SAVE',
     'FORM_GENERATOR_FORM',
     'FORM_RESPONSE_FORM',
-    'FORM_THEME_CHOICES',
+    'FORM_STYLE_CHOICES',
     'FORM_MANAGER',
     'FORM_GENERATOR_RESPONSE_MODEL',
     'FORM_GENERATOR_SERIALIZER',
